@@ -13,7 +13,7 @@
     Library General Public License for more details.
 
     You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
+    along with this library; see the file COPYING.LGPL-2.  If not, write to
     the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
     Boston, MA 02110-1301, USA.
 */
@@ -105,7 +105,7 @@ public:
      * Only use this constructor if you don't use KFindDialog, or if
      * you use it as a modal dialog.
      */
-    KReplace(const QString &pattern, const QString &replacement, long options, QWidget *parent = 0);
+    KReplace(const QString &pattern, const QString &replacement, long options, QWidget *parent = nullptr);
     /**
      * This is the recommended constructor if you also use KReplaceDialog (non-modal).
      * You should pass the pointer to it here, so that when a message box
